@@ -8,14 +8,14 @@
  * All Rights Reserved.
  ************************************************************************************/
 $languageStrings = array(
-	'SINGLE_ModComments'           => 'Kommentar'                   , 
+	'SINGLE_ModComments'           => 'Comment'                     , 
 	'LBL_RECORDS_LIST'             => 'Comments List'               , 
-	'LBL_MODCOMMENTS_INFORMATION'  => 'Allgemeine Information'      , 
-	'LBL_OTHER_INFORMATION'        => 'andere Information'          , 
+	'LBL_MODCOMMENTS_INFORMATION'  => 'Comments'                    , 
+	'LBL_OTHER_INFORMATION'        => 'Other Information'           , 
 	'LBL_ADDING_COMMENT'           => 'Adding Comment'              , 
 	'LBL_WRITE_YOUR_COMMENT_HERE'  => 'Enter comments here'         , 
-	'Comment'                      => 'Kommentar'                   , 
-	'Creator'                      => 'erzeugt von'                 , 
-	'Related To Comments'          => 'bezogen auf'                 , 
-	'LBL_COMMENTED_AT'             => 'Kommentiert am'              , 
+	'Comment'                      => 'Comment'                     , 
+	'Creator'                      => 'Creator'                     , 
+	'Related To Comments'          => 'Se refera la'                , 
+	'LBL_COMMENTED_AT'             => 'A comentat la'               , 
 );
\ No newline at end of file
