@@ -10,23 +10,23 @@
 
 $languageStrings = Array(
     'Rss'=>'Rss',
-    'LBL_RSS_FEED_SOURCES' => 'RSS hírcsatorna Források',
-    'LBL_ADD_FEED_SOURCE' => 'Add hírcsatorna forrás',
-    'LBL_FEEDS_LIST_FROM' => 'Hírcsatornák listája A',
-    'LBL_SET_AS_DEFAULT' => 'Beállítás alapértelmezettként',
-    'LBL_SENDER' => 'adó',
-    'LBL_FEED_SOURCE' => 'Takarmány Forrás',
-    'LBL_ENTER_FEED_SOURCE' => 'Adja meg a hírcsatorna forrás',  
-    'SINGLE_Rss' => 'RSS hírcsatorna',
+    'LBL_RSS_FEED_SOURCES' => 'Surse RSS Feed',
+    'LBL_ADD_FEED_SOURCE' => 'Adaugă alimentare Sursa',
+    'LBL_FEEDS_LIST_FROM' => 'Fluxuri Lista Din',
+    'LBL_SET_AS_DEFAULT' => 'Setare ca implicit',
+    'LBL_SENDER' => 'transmițător',
+    'LBL_FEED_SOURCE' => 'Sursa de alimentare',
+    'LBL_ENTER_FEED_SOURCE' => 'Introduceți alimentare Sursa',  
+    'SINGLE_Rss' => 'RSS Feed',
 );
 
 $jsLanguageStrings = array(
-	'JS_RSS_SUCCESSFULLY_SAVED' => 'Rss Sikeresen mentve',
-    'JS_INVALID_RSS_URL' => 'Invalid Rss Url',
-    'JS_RSS_MADE_AS_DEFAULT' => 'Rss Made alapértelmezett',
+	'JS_RSS_SUCCESSFULLY_SAVED' => 'RSS salvat cu succes',
+    'JS_INVALID_RSS_URL' => 'Invalid Adresă URL RSS',
+    'JS_RSS_MADE_AS_DEFAULT' => 'RSS Made ca implicit',
     
 
-  'JS_NO_RECORDS' => 'Nincs Bejegyzés',
+  'JS_NO_RECORDS' => 'Nu Există Înregistrări',
 
 );
 
