@@ -503,7 +503,7 @@ function vtws_CreateCompanyLogoFile($fieldname) {
 
 function vtws_getActorEntityName ($name, $idList) {
 	$db = PearDatabase::getInstance();
-	if (!is_array($idList) && count($idList) == 0) {
+	if (!is_array($idList) && php7_count($idList) == 0) {
 		return array();
 	}
 	$entity = VtigerWebserviceObject::fromName($db, $name);
@@ -512,7 +512,7 @@ function vtws_getActorEntityName ($name, $idList) {
 
 function vtws_getActorEntityNameById ($entityId, $idList) {
 	$db = PearDatabase::getInstance();
-	if (!is_array($idList) && count($idList) == 0) {
+	if (!is_array($idList) && php7_count($idList) == 0) {
 		return array();
 	}
 	$nameList = array();
@@ -918,7 +918,7 @@ function vtws_updateWebformsRoundrobinUsersLists($ownerId, $newOwnerId) {
 					}
 					$usersList = $revisedUsersList;
 				}
-				if (count($usersList) == 0) {
+				if (php7_count($usersList) == 0) {
 					$db->pquery('UPDATE vtiger_webforms SET roundrobin_userid = ?,roundrobin = ? where id =?', array("--None--", 0, $webformId));
 				} else {
 					$usersList = json_encode($usersList);
@@ -962,7 +962,7 @@ function vtws_transferOwnershipForWorkflowTasks($ownerModel, $newOwnerModel) {
 		require_once("modules/com_vtiger_workflow/VTTaskManager.inc");
 		require_once 'modules/com_vtiger_workflow/tasks/'.$className.'.inc';
 		$unserializeTask = unserialize($task);
-		if(array_key_exists("field_value_mapping",$unserializeTask)) {
+		if(property_exists($unserializeTask, "field_value_mapping")) {
 			$fieldMapping = Zend_Json::decode($unserializeTask->field_value_mapping);
 			if (!empty($fieldMapping)) {
 				foreach ($fieldMapping as $key => $condition) {
@@ -985,7 +985,7 @@ function vtws_transferOwnershipForWorkflowTasks($ownerModel, $newOwnerModel) {
 			}
 		} else {
 			//For VTCreateTodoTask and VTCreateEventTask
-			if(array_key_exists('assigned_user_id', $unserializeTask)){
+			if(property_exists($unserializeTask, 'assigned_user_id')){
 				$value = $unserializeTask->assigned_user_id;
 				if($value == $ownerId) {
 					$unserializeTask->assigned_user_id = $newOwnerId;
@@ -1291,7 +1291,7 @@ function vtws_filedetails($fileData){
         $fileName = $fileData['name'];
         $fileType = $fileData['type'];
         $fileName = html_entity_decode($fileName, ENT_QUOTES, vglobal('default_charset'));
-        $filenamewithpath = $fileData['path'].'_'.$fileData['encName'];
+        $filenamewithpath = $fileData['path'].$fileData['attachmentsid'].'_'.$fileData['storedname'];
         $filesize = filesize($filenamewithpath);
         $fileDetails['fileid'] = $fileData['attachmentsid'];
         $fileDetails['filename'] = $fileName;
