@@ -12,6 +12,9 @@
   *      @link http://kcfinder.sunhater.com
   */
 
+require_once __DIR__ . '/../../include/utils/VtlibUtils.php';
+require_once __DIR__ . '/../../vtlib/Vtiger/Functions.php';
+
 class uploader {
     protected $config = array();
     protected $opener = array();
