@@ -25,7 +25,7 @@ class Inventory_ProductsPopupAjax_View extends Inventory_ProductsPopup_View {
 		return 'Products';
 	}
 	
-	function preProcess(Vtiger_Request $request) {
+	function preProcess(Vtiger_Request $request, $display = true) {
 		return true;
 	}
 
