@@ -391,7 +391,7 @@ class Vtiger_Util_Helper {
 		$fileName = rtrim($fileName, '\\/<>?*:"<>|');
 
 		$fileNameParts = explode('.', $fileName);
-		$countOfFileNameParts = count($fileNameParts);
+		$countOfFileNameParts = php7_count($fileNameParts);
 		$badExtensionFound = false;
 
 		for ($i=0; $i<$countOfFileNameParts; $i++) {
@@ -585,7 +585,7 @@ class Vtiger_Util_Helper {
 				   $advFilterFieldInfoFormat = array();
 				   $fieldName = $fieldSearchInfo[0];
 				   preg_match('/(\w+) ; \((\w+)\) (\w+)/', $fieldName, $matches);
-					if (count($matches) != 0) {
+					if (php7_count($matches) != 0) {
 						list($full, $referenceParentField, $referenceModule, $referenceFieldName) = $matches;
 						$referenceModuleModel = Vtiger_Module_Model::getInstance($referenceModule);
 						$fieldInfo = Vtiger_Field_Model::getInstance($referenceFieldName, $referenceModuleModel);
@@ -642,7 +642,7 @@ class Vtiger_Util_Helper {
 				   $advFilterFieldInfoFormat['column_condition'] = $groupConditionGlue;
 				   $groupColumnsInfo[] = $advFilterFieldInfoFormat;
 			}
-			$noOfConditions = count($groupColumnsInfo);
+			$noOfConditions = php7_count($groupColumnsInfo);
 			//to remove the last column condition
 			$groupColumnsInfo[$noOfConditions-1]['column_condition']  = '';
 			$groupConditionInfo['columns'] = $groupColumnsInfo;
@@ -651,7 +651,7 @@ class Vtiger_Util_Helper {
 			$groupIterator++;
 		}
 		//We aer removing last condition since this condition if there is next group and this is the last group
-		unset($advFilterConditionFormat[count($advFilterConditionFormat)-1]['condition']);
+		unset($advFilterConditionFormat[php7_count($advFilterConditionFormat)-1]['condition']);
 		return $advFilterConditionFormat;
 
 	}
@@ -701,7 +701,7 @@ class Vtiger_Util_Helper {
 	* @return returns default value for data type if match case found
 	* else returns empty string
 	*/
-   function getDefaultMandatoryValue($dataType) {
+   static function getDefaultMandatoryValue($dataType) {
 	   $value;
 	   switch ($dataType) {
 		   case 'date':
@@ -939,7 +939,7 @@ class Vtiger_Util_Helper {
 		}
 
 		// see how many we have
-		$i = count($matches['browser']);
+		$i = php7_count($matches['browser']);
 		if ($i != 1) {
 			//we will have two since we are not using 'other' argument yet
 			//see if version is before or after the name
@@ -1181,7 +1181,7 @@ class Vtiger_Util_Helper {
 									$value = vtws_getWebserviceEntityId("DocumentFolders", "1");
 									break;
 			case 'reference'	:	$referenceFieldModule = $fieldModel->getReferenceList(true);
-									if (count($referenceFieldModule) > 0) {
+									if (php7_count($referenceFieldModule) > 0) {
 										$user = Users_Record_Model::getCurrentUserModel();
 										$referenceModule = $referenceFieldModule[0];
 										$referenceFieldModuleModel = Vtiger_Module_Model::getInstance($referenceModule);
@@ -1217,7 +1217,7 @@ class Vtiger_Util_Helper {
 												if (isset($source) && !empty($source)) {
 													$element['source'] = $source;
 												}
-												if (!function_exists(vtws_create)) {
+												if (!function_exists("vtws_create")) {
 													include_once 'include/Webservices/Create.php';
 												}
 												$entity = vtws_create($referenceModule, $element, $user);
@@ -1263,7 +1263,7 @@ class Vtiger_Util_Helper {
     public static function validateFieldValue($fieldValue,$fieldModel){
         $fieldDataType = $fieldModel->getFieldDataType();
         $fieldInfo = $fieldModel->getFieldInfo();
-        $editablePicklistValues = $fieldInfo['editablepicklistvalues'];
+        $editablePicklistValues = isset($fieldInfo['editablepicklistvalues'])? $fieldInfo['editablepicklistvalues'] : null;
         if($fieldValue && $fieldDataType == 'picklist'){
            if(!empty($editablePicklistValues) && !isset($editablePicklistValues[$fieldValue])){
                 $fieldValue = null;
@@ -1271,7 +1271,7 @@ class Vtiger_Util_Helper {
         }elseif(!empty($fieldValue) && $fieldDataType == 'multipicklist'){
             if(!empty($editablePicklistValues)){
                 foreach($fieldValue as $key => $value){
-                    if(!isset($editablePicklistValues[$fieldValue])){
+                    if(!isset($editablePicklistValues[$value])){
                         unset($fieldValue[$key]);
                     }
                 }
