@@ -612,16 +612,16 @@ class Vtiger_Module_Model extends Vtiger_Module {
 	public function getConfigureRelatedListFields(){
 		$showRelatedFieldModel = $this->getHeaderAndSummaryViewFieldsList();
 		$relatedListFields = array();
-		if(count($showRelatedFieldModel) > 0) {
+		if(php7_count($showRelatedFieldModel) > 0) {
 			foreach ($showRelatedFieldModel as $key => $field) {
 				$relatedListFields[$field->get('column')] = $field->get('name');
 			}
 		}
 
-		if(count($relatedListFields)>0) {
+		if(php7_count($relatedListFields)>0) {
 			$nameFields = $this->getNameFields();
 			foreach($nameFields as $fieldName){
-				if(!$relatedListFields[$fieldName]) {
+				if(!isset($relatedListFields[$fieldName]) || !$relatedListFields[$fieldName]) {
 					$fieldModel = $this->getField($fieldName);
 					$relatedListFields[$fieldModel->get('column')] = $fieldModel->get('name');
 				}
@@ -1389,7 +1389,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
 	 * @return <Array> list of field models <Vtiger_Field_Model>
 	 */
 	public function getSummaryViewFieldsList() {
-		if (!$this->summaryFields) {
+		if (!isset($this->summaryFields) || !$this->summaryFields) {
 			$summaryFields = array();
 			$fields = $this->getFields();
 			foreach ($fields as $fieldName => $fieldModel) {
@@ -1407,7 +1407,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
 	 * @return <Array> list of field models <Vtiger_Field_Model>
 	 */
 	public function getHeaderViewFieldsList() {
-		if (!$this->headerFields) {
+		if (!isset($this->headerFields) || !$this->headerFields) {
 			$headerFields = array();
 			$fields = $this->getFields();
 			foreach ($fields as $fieldName => $fieldModel) {
@@ -1425,7 +1425,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
 	 * @return <Array> list of field models <Vtiger_Field_Model>
 	 */
 	public function getHeaderAndSummaryViewFieldsList() {
-		if(!$this->relationListViewFields) {
+		if(!isset($this->relationListViewFields) || !$this->relationListViewFields) {
 			$summaryViewFields = $this->getSummaryViewFieldsList();
 			$headerViewFields = $this->getHeaderViewFieldsList();
 			$allRelationListViewFields = array_merge($headerViewFields,$summaryViewFields);
@@ -1523,7 +1523,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
 			$relatedListFields['filestatus'] = 'filestatus';
 		}
 
-		if(count($relatedListFields) > 0) {
+		if(php7_count($relatedListFields) > 0) {
 			$currentUser = Users_Record_Model::getCurrentUserModel();
 			$queryGenerator = new QueryGenerator($relatedModuleName, $currentUser);
 			$queryGenerator->setFields($relatedListFields);
@@ -1783,7 +1783,7 @@ class Vtiger_Module_Model extends Vtiger_Module {
 	public function getPopupViewFieldsList(){
 		$summaryFieldsList = $this->getHeaderAndSummaryViewFieldsList();
 
-		if(count($summaryFieldsList) > 0){
+		if(php7_count($summaryFieldsList) > 0){
 			 $popupFields = array_keys($summaryFieldsList);
 		}else{
 			$popupFields = array_values($this->getRelatedListFields());
