@@ -19,6 +19,13 @@ class Vtiger_List_View extends Vtiger_Index_View {
 	function __construct() {
 		parent::__construct();
 	}
+	
+	public function requiresPermission(Vtiger_Request $request){
+		$permissions = parent::requiresPermission($request);
+		
+		$permissions[] = array('module_parameter' => 'module', 'action' => 'DetailView');
+		return $permissions;
+	}
 
 	function preProcess(Vtiger_Request $request, $display=true) {
 		parent::preProcess($request, false);
@@ -32,7 +39,7 @@ class Vtiger_List_View extends Vtiger_Index_View {
 		}
 
 		$viewer = $this->getViewer($request);
-		$cvId = $this->viewName;
+		$cvId = isset($this->viewName) ? $this->viewName : 0;
 
 		if(!$cvId) {
 			$customView = new CustomView();
@@ -45,14 +52,14 @@ class Vtiger_List_View extends Vtiger_Index_View {
 		if(!empty($tag)) {
 			$listViewSessionKey .='_'.$tag;
 		}
+                
+                $this->listViewModel = Vtiger_ListView_Model::getInstance($moduleName, $cvId, $listHeaders);
+		$orderParams = $this->listViewModel->getSortParamsSession($listViewSessionKey);
 
-		$orderParams = Vtiger_ListView_Model::getSortParamsSession($listViewSessionKey);
-
-		if(empty($listHeaders)) {
+		if(empty($listHeaders) && is_array($orderParams)) {
 			$listHeaders = $orderParams['list_headers'];
 		}
 
-		$this->listViewModel = Vtiger_ListView_Model::getInstance($moduleName, $cvId, $listHeaders);
 		$linkParams = array('MODULE'=>$moduleName, 'ACTION'=>$request->get('view'));
 		$viewer->assign('CUSTOM_VIEWS', CustomView_Record_Model::getAllByGroup($moduleName));
 		$this->viewName = $request->get('viewname');
@@ -167,50 +174,57 @@ class Vtiger_List_View extends Vtiger_Index_View {
 		$tag = $request->get('tag');
 		$requestViewName = $request->get('viewname');
 		$tagSessionKey = $moduleName.'_TAG';
+                
+                if(!$this->listViewModel) {
+			$listViewModel = Vtiger_ListView_Model::getInstance($moduleName, $cvId, $listHeaders);
+		} else {
+			$listViewModel = $this->listViewModel;
+		}
 
 		if(!empty($requestViewName) && empty($tag)) {
 			unset($_SESSION[$tagSessionKey]);
 		}
 
 		if(empty($tag)) {   
-			$tagSessionVal = Vtiger_ListView_Model::getSortParamsSession($tagSessionKey);
+			$tagSessionVal = $listViewModel->getSortParamsSession($tagSessionKey);
 			if(!empty($tagSessionVal)) {
 				$tag = $tagSessionVal;
 			}
 		}else{
-			Vtiger_ListView_Model::setSortParamsSession($tagSessionKey, $tag);
+			$listViewModel->setSortParamsSession($tagSessionKey, $tag);
 		}
 
+                if(empty($cvId)) {
+			$customView = new CustomView();
+			$cvId = $customView->getViewId($moduleName);
+		}
+                
 		$listViewSessionKey = $moduleName.'_'.$cvId;
 		if(!empty($tag)) {
 			$listViewSessionKey .='_'.$tag;
 		}
 
-		if(empty($cvId)) {
-			$customView = new CustomView();
-			$cvId = $customView->getViewId($moduleName);
-		}
-
-		$orderParams = Vtiger_ListView_Model::getSortParamsSession($listViewSessionKey);
+		$orderParams = $listViewModel->getSortParamsSession($listViewSessionKey);
 		if($request->get('mode') == 'removeAlphabetSearch') {
-			Vtiger_ListView_Model::deleteParamsSession($listViewSessionKey, array('search_key', 'search_value', 'operator'));
+			$listViewModel->deleteParamsSession($listViewSessionKey, array('search_key', 'search_value', 'operator'));
 			$searchKey = '';
 			$searchValue = '';
 			$operator = '';
 		}
 		if($request->get('mode') == 'removeSorting') {
-			Vtiger_ListView_Model::deleteParamsSession($listViewSessionKey, array('orderby', 'sortorder'));
+			$listViewModel->deleteParamsSession($listViewSessionKey, array('orderby', 'sortorder'));
 			$orderBy = '';
 			$sortOrder = '';
 		}
-		if(empty($listHeaders)) {
+		if(empty($listHeaders) && is_array($orderParams)) {
 			$listHeaders = $orderParams['list_headers'];
 		}
-
-		 if(!empty($tag) && empty($tagParams)){
-			$tagParams = $orderParams['tag_params'];
+                
+                
+		if(!empty($tag) && empty($tagParams) && is_array($orderParams)){
+                    $tagParams = $orderParams['tag_params'];
 		}
-
+                
 		if(empty($orderBy) && empty($searchValue) && empty($pageNumber)) {
 			if($orderParams) {
 				$pageNumber = $orderParams['page'];
@@ -219,6 +233,9 @@ class Vtiger_List_View extends Vtiger_Index_View {
 				$searchKey = $orderParams['search_key'];
 				$searchValue = $orderParams['search_value'];
 				$operator = $orderParams['operator'];
+                                if(empty($tagParams)){
+					$tagParams = $orderParams['tag_params'];
+				}
 				if(empty($searchParams)) {
 					$searchParams = $orderParams['search_params']; 
 				}
@@ -234,7 +251,7 @@ class Vtiger_List_View extends Vtiger_Index_View {
 			if(!empty($listHeaders)) {
 				$params['list_headers'] = $listHeaders;
 			}
-			Vtiger_ListView_Model::setSortParamsSession($listViewSessionKey, $params);
+			$listViewModel->setSortParamsSession($listViewSessionKey, $params);
 		}
 		if($sortOrder == "ASC"){
 			$nextSortOrder = "DESC";
@@ -250,11 +267,6 @@ class Vtiger_List_View extends Vtiger_Index_View {
 			$pageNumber = '1';
 		}
 
-		if(!$this->listViewModel) {
-			$listViewModel = Vtiger_ListView_Model::getInstance($moduleName, $cvId, $listHeaders);
-		} else {
-			$listViewModel = $this->listViewModel;
-		}
 		$currentUser = Users_Record_Model::getCurrentUserModel();
 
 		$linkParams = array('MODULE'=>$moduleName, 'ACTION'=>$request->get('view'), 'CVID'=>$cvId);
@@ -287,7 +299,7 @@ class Vtiger_List_View extends Vtiger_Index_View {
 		if(empty($searchParams)) {
 			$searchParams = array();
 		}
-		if(count($searchParams) == 2 && empty($searchParams[1])) {
+		if(php7_count($searchParams) == 2 && empty($searchParams[1])) {
 			unset($searchParams[1]);
 		}
 
@@ -332,7 +344,7 @@ class Vtiger_List_View extends Vtiger_Index_View {
 			$this->noOfEntries = $pagingModel->get('_listcount');
 		}
 		if(!$this->noOfEntries) {
-			$noOfEntries = count($this->listViewEntries);
+			$noOfEntries = php7_count($this->listViewEntries);
 		} else {
 			$noOfEntries = $this->noOfEntries;
 		}
@@ -351,15 +363,15 @@ class Vtiger_List_View extends Vtiger_Index_View {
 		}
 		$viewer->assign('PAGE_NUMBER',$pageNumber);
 
-		if(!$this->moduleFieldStructure) {
+		if(!isset($this->moduleFieldStructure) || !$this->moduleFieldStructure) {
 			$recordStructure = Vtiger_RecordStructure_Model::getInstanceForModule($listViewModel->getModule(), Vtiger_RecordStructure_Model::RECORD_STRUCTURE_MODE_FILTER);
 			$this->moduleFieldStructure = $recordStructure->getStructure();   
 		}
 
-		if(!$this->tags) {
+		if(!isset($this->tags) || !$this->tags) {
 			$this->tags = Vtiger_Tag_Model::getAllAccessible($currentUser->id, $moduleName);
 		}
-		if(!$this->allUserTags) {
+		if(!isset($this->allUserTags) || !$this->allUserTags) {
 			$this->allUserTags = Vtiger_Tag_Model::getAllUserTags($currentUser->getId());
 		}
 
@@ -408,7 +420,7 @@ class Vtiger_List_View extends Vtiger_Index_View {
 		$viewer->assign('IS_MODULE_EDITABLE', $listViewModel->getModule()->isPermitted('EditView'));
 		$viewer->assign('IS_MODULE_DELETABLE', $listViewModel->getModule()->isPermitted('Delete'));
 		$viewer->assign('SEARCH_DETAILS', $searchParams);
-		$viewer->assign('TAG_DETAILS', $tagParams);
+                $viewer->assign('TAG_DETAILS', $tagParams);
 		$viewer->assign('NO_SEARCH_PARAMS_CACHE', $request->get('nolistcache'));
 		$viewer->assign('STAR_FILTER_MODE',$starFilterMode);
 		$viewer->assign('VIEWID', $cvId);
